% Example 1 in "Wavelet density estimation for stratified size-biased sample"
% by Pepa Ramirez & Brani Vidakovic.

% In this example we consider a U(0,1) underlying distribution and one
% stratum where the biasing function is g(y) = exp(y).
%
%  The program calls to:
%           1) Phijk.m -- Daubechies-Lagarias Algorithm. 
%           2) dwtr.m and idwtr.m -- forward and inverse wavelet transform.
%           3) loc_lin.m and kernel.m -- local linear smoother with a
%           Gaussian kernel.
%
%--------------------------------------------------------------------------
close all
clear all
lw = 2;  
set(0, 'DefaultAxesFontSize', 16);
fs = 14;
msize = 5;

%---- Generate de biased sample size & estimate mu.
n = 1000; % we first simulate n observations from the underlying function and
% then we obtain the biased sample (of size less than n!).
y = []; %biased sample
for i = 1:n
    u1 = rand;
    u2 = rand;
    crit = u2 * exp(1)/(exp(1) - 1) ; 
    if crit < exp(u1)/(exp(1)-1)
        y = [y u1];
    end
end
n = length(y) % biased sample size.

%Biasing function: g(y) = exp(y).
%Estimation of mu,
muhat = n./sum(exp(-y));


%--------------------------------------------------------------------------
%--- Apply Daubechies Lagarias to obtain the linear wavelet estimate (equation 4)

% Choose an orthonormal QMF Filter for the D-L algorithm
% for example Symmlet 4:
filter = [-0.07576571478934,  -0.02963552764595,   0.49761866763246,   0.80373875180522,...
   0.29785779560554,  -0.09921954357694,  -0.01260396726226,   0.03222310060407];
%To try another filter: wf = MakeONFilterExt(Type,Par)
J=7; % default coarsest level
cs =[];
for k = 0:(2^J-1)
    cJk = 0;
    for i = 1:n
        cJk = cJk + Phijk(y(i), J, k, filter, 20)*exp(-y(i)); 
        %Evaluation of the scaling function corresponding to an Orthogonal 
        %MRA by Daubechies-Lagarias Algorithm.
    end
    cJk = muhat/n * cJk;
    cs =[cs cJk];
end
linear_est = 2^(J/2) * cs; % This is the linear (or "raw") estimator (equation 5)

%--------------------------------------------------------------------------
% How does the linear estimator look like?
a = linspace(0,1, length(linear_est));
figure(1);
plot(a, linspace(1,1,length(a)),'k-');% underlying unobserved density f^X
hold on
plot( a, exp(a),'k-.') % observed f^Y
hold on
plot(a,linear_est,'k:')
title('Linear wavelet estimator based on projection')

%--------------------------------------------------------------------------
% How does the linear estimator look like after hard thresholding?

wf = [0.0386 -0.1270 -0.0772 0.6075 0.7457 0.2266]; % For example, filter
% Coiflet(1). To try another filter: wf = MakeONFilterExt(Type,Par)

csw = dwtr(linear_est, 6, wf); % Forward wavelet transformation 
nn = length(csw);
nn2 = nn/2;
finest = csw(nn2+1:nn); %finest details
sigma = 1.4826*median(abs(finest-median(finest)));
lambda = sqrt( 2 * log(nn)) * sigma;
cswt = csw .* ( abs(csw) > lambda); %hard threshold
smooth_th = idwtr(cswt, 6, wf); % Inverse wavelet transformation

figure(2);
plot(a, linspace(1,1,length(a)),'k-');% underlying unobserved density f^X
hold on
plot( a, exp(a),'k-.') % observed f^Y
hold on
plot(a, smooth_th,'k--')
title('Linear wavelet estimator after thresholding')
%--------------------------------------------------------------------------

% How does it look like after local linear smoothing?
h = 0.080; % bandwidth
smooth_ll=[];
for j=1:100
  smooth_ll = [smooth_ll loc_lin(j/100, a, linear_est, h)];
end
figure(3)
plot(a, linspace(1,1,length(a)),'k-');% underlying unobserved density f^X
hold on
plot( a, exp(a),'k-.') % observed f^Y
hold on
plot((1:100)/100, smooth_ll, 'k--')
title('Smoothed linear wavelet estimator')


