% Example 4 in "Wavelet density estimation for stratified size-biased sample"
% by Pepa Ramirez & Brani Vidakovic.

% This example shows a comparison between the wavelet-based estimator and
% the naive one.
% As it is said in Efromovich (2004),the naive estimator "is rate
% inadmissible whenever the biasing function is not as smooth as the
% underlying density f_X", thus, "since the smoothness of f_X is typically
% unkwnown, it is better to avoid it".
%
% Here we have chosen a smooth underlying f_X, a Beta(2,2) and a
% discontinuous biasing function, g(y) = 1, if x<0.4 (that is, no bias for
% x<0.4), and g(x) = x, if x>=0.4.
% 
% The naive estimator is computed as fX_hat = mu_hat*fY_hat/g, where fY_hat
% is estimated using ksdensity.m (gaussian kernel).

%  The program calls to:
%           1) Phijk.m -- Daubechies-Lagarias Algorithm. 
%           2) dwtr.m and idwtr.m -- forward and inverse wavelet transform.
%           3) loc_lin.m and kernel.m -- local linear smoother with a
%           Gaussian kernel.
%
%--------------------------------------------------------------------------
close all
clear all
lw = 2;  
set(0, 'DefaultAxesFontSize', 16);
fs = 14;
msize = 5;

%---- Generate de biased sample size & estimate mu.

n = 800; % we simulate n observations from the underlying function and then
% we obtain the biased sample with size less than n.
x = betarnd(2,2,n,1);
y = []; %biased sample
y1 = find(x<.4);
y2 = find(x>=.4);
y1 = x(y1); % we will keep these ones
y2 = x(y2);
s = [];
for i = 1:length(y2)
    if unifrnd(0,1)<y2(i) 
        s = [s y2(i)];
    end
end
y = [y1' s];
ly1 = length(y1);
ls = length(s);
n = ly1 + ls
muhat = n./(ly1 + sum(1./s));

a = linspace(0.01,1, 128);
[fY_est] = ksdensity(y,a); % estimated fY. 

%--------------------------------------------------------------------------
%--- Apply Daubechies Lagarias to obtain the linear wavelet estimate (equation 4)

% Choose an orthonormal QMF Filter for the D-L algorithm
% for example Symmlet 4:
filter = [-0.07576571478934,  -0.02963552764595,   0.49761866763246,   0.80373875180522,...
   0.29785779560554,  -0.09921954357694,  -0.01260396726226,   0.03222310060407];
J=7; % default coarsest level.
cs =[];
for k = 0:(2^J-1)
    cJk = 0;
for i = 1:ly1
    cJk = cJk + Phijk(y(i), J, k, filter, 20)/1; %Evaluation of the scaling function corresponding to an Orthogonal 
            %MRA by Daubechies-Lagarias Algorithm.
end

for i = 1:ls
    cJk = cJk + Phijk(s(i), J, k, filter, 20)/s(i); %Evaluation of the scaling function corresponding to an Orthogonal 
            %MRA by Daubechies-Lagarias Algorithm.
end

cJk = muhat/n * cJk;
cs =[cs cJk];
end
linear_est = 2^(J/2) * cs; % This is the linear (or "raw") estimator (equation 5)

%--------------------------------------------------------------------------
% How does the linear estimator look like?
a = linspace(0,1, length(linear_est));
figure(1);
plot( a, 1./beta(2,2).* a .* (1-a),'k-');% underlying unobserved density f^X
hold on
plot(a,fY_est,'k-.')
hold on
plot(a,linear_est,'k:')
%title('Linear wavelet estimator based on projection')
xlabel('y')
ylabel('f(y)')
legend('f^X(y)','f^Y(y)','f^X_{est}(y)')

%--------------------------------------------------------------------------
% How does the linear estimator look like after hard thresholding?

wf = [0.0386 -0.1270 -0.0772 0.6075 0.7457 0.2266]; % Filter Coiflet(1)
csw = dwtr(linear_est, 6, wf); % Forward wavelet transformation 
nn = length(csw);
nn2 = nn/2;
finest = csw(nn2+1:nn); %finest details
sigma = 1.4826*median(abs(finest-median(finest)));
lambda = sqrt( 2 * log(nn)) * sigma;
cswt = csw .* ( abs(csw) > lambda); %hard threshold
smooth_th = idwtr(cswt, 6, wf); % Inverse wavelet transformation

figure(2);
plot( a, 1./beta(2,2).* a .* (1-a),'k-');% underlying unobserved density f^X
hold on
plot(a,fY_est,'k-.'); % observed density
hold on
plot(a, smooth_th,'k--')
%title('Linear wavelet estimator after thresholding')
xlabel('y')
ylabel('f(y)')
legend('f^X(y)','f^Y(y)','f^X_{est th}(y)')

%--------------------------------------------------------------------------
% How does the linear estimator look like after local linear smoothing?
h = 0.080; % bandwidth
smooth_ll=[];
for j=1:100
  smooth_ll = [smooth_ll loc_lin(j/100, a, linear_est, h)];
end
figure(3)
plot( a, 1./beta(2,2).* a .* (1-a),'k-');% underlying unobserved density f^X
hold on
plot(a,fY_est,'k-.'); % observed f^Y
hold on
plot((1:100)/100, smooth_ll, 'k--')
%title('Smoothed linear wavelet estimator')
xlabel('y')
ylabel('f(y)')
legend('f^X(y)','f^Y(y)','f^X_{est loc.lin}(y)')


%--------------------------------------------------------------------------
% How does the NAIVE estimator look like?
[fY_est] = ksdensity(y,a);
a1 = a(find(a<.4));
a2 = a(find(a>=.4));
f_est_naive1 = exp(log(muhat)+log(fY_est(find(a<.4))));
f_est_naive2 = exp(log(muhat)+log(fY_est(find(a>=.4)))-log(a2));

figure(4)
plot(a1,f_est_naive1,'k--') %naive estimator part 1
hold on
plot(a2,f_est_naive2,'k--') %naive estimator part 2
hold on
plot( a, 1./beta(2,2).* a .* (1-a),'k');% underlying unobserved density f^X
hold on
plot(a,fY_est,'k-.'); % observed density
%title('Naive estimator')
xlabel('y')
ylabel('f(y)')
legend('f^X_{est naive}(y)','f^X_{est naive}(y)','f^X(y)','f^Y(y)')



